using System;
using cAlgo.API;
using cAlgo.API.Indicators;

namespace cAlgo.Robots
{
    [Robot]
    public class NewRobot : Robot
    {
        [Parameter("Vol", DefaultValue = 10000)]
        public int Vol { get; set; }
        
        [Parameter("SL", DefaultValue = 500)]
        public int SL { get; set; }
        
        [Parameter("TP", DefaultValue = 500)]
        public int TP { get; set; }
        
        [Parameter("Tral_Start", DefaultValue = 200)]
        public int Tral_Start { get; set; }
        
        [Parameter("Tral_Stop", DefaultValue = 100)]
        public int Tral_Stop { get; set; }
        
        [Parameter("MA_price1")]
        public DataSeries MA_price1 { get; set; }
        
        [Parameter("MA_period1", DefaultValue = 8)]
        public int MA_period1 { get; set; }
        
        [Parameter("MAType1")]
        public MovingAverageType MAType1 { get; set; }
        
        [Parameter("MA_price2")]
        public DataSeries MA_price2 { get; set; }
        
        [Parameter("MA_period2", DefaultValue = 40)]
        public int MA_period2 { get; set; }
        
        [Parameter("MAType2")]
        public MovingAverageType MAType2 { get; set; }
        
        [Parameter("DVBuySell", DefaultValue = 0.0011)]
        public double DVBuySell { get; set; }
        
        [Parameter("DVStayOut", DefaultValue = 0.0079)]
        public double DVStayOut { get; set; }
                
        
        
        
        private MovingAverage MA1; 
        private MovingAverage MA2;      
        private Position position1;
        private int a;
        
        protected override void OnStart()
        {
        MA1 = Indicators.MovingAverage(MA_price1, MA_period1, MAType1);
        MA2 = Indicators.MovingAverage(MA_price2, MA_period2, MAType2);
        Print("Welcome to the world of infinite financial possibilities!");   
        }
        
         protected override void OnPositionOpened(Position openedPosition)
        {
            position1 = openedPosition;
            
            if (position1.TradeType == TradeType.Buy)
            {
            Trade.ModifyPosition(openedPosition, position1.EntryPrice-SL*Symbol.PointSize, position1.EntryPrice+TP*Symbol.PointSize);
            Print("StopLoss and TakeProfit were successfully established");
            }
            
            if (position1.TradeType == TradeType.Sell)
            {
            Trade.ModifyPosition(openedPosition, position1.EntryPrice+SL*Symbol.PointSize, position1.EntryPrice-TP*Symbol.PointSize);
            Print("StopLoss and TakeProfit were successfully established");
            }
        }
        

        protected override void OnTick()
        {   
  
        double ma1=MA1.Result[MA1.Result.Count-1];
        double ma2=MA2.Result[MA2.Result.Count-1];
        
        double ma3=MA1.Result[MA1.Result.Count-2];
        double ma4=MA2.Result[MA2.Result.Count-2];
        
        double div1=ma1-ma2;
        double div2=ma3-ma4;
        
        double diver=div1-div2;
        
        double Bid=Symbol.Bid;
        double Ask=Symbol.Ask;
        double Point=Symbol.PointSize;
         
        if (Trade.IsExecuting) return;
        
          if (diver>=DVBuySell && diver<=DVStayOut && a==0)
          {
          Trade.CreateBuyMarketOrder(Symbol, Vol);
          Print("Trade BUY was successfully open");
          a=1;
          }
          
          if (diver<=-DVBuySell && diver>=-DVStayOut && a==0)
          {
          Trade.CreateSellMarketOrder(Symbol, Vol);  
          Print("Trade SELL was successfully open");
          a=1;
          } 

         foreach (var position in Account.Positions)
            {
            	if(position.SymbolCode == Symbol.Code)
            	{
            	
            		if(position.TradeType == TradeType.Buy)	
            		{
            		if (Bid-position.EntryPrice>=Tral_Start*Point)
            		if (Bid-Tral_Stop*Point>=position.StopLoss)
            		Trade.ModifyPosition(position, Bid-Tral_Stop*Point, position.TakeProfit);
            		}
            			
            		if(position.TradeType == TradeType.Sell)	
            		{
            		if (position.EntryPrice-Ask>=Tral_Start*Point)
            		if (Ask+Tral_Stop*Point<=position.StopLoss)
            		Trade.ModifyPosition(position, Ask+Tral_Stop*Point, position.TakeProfit);
            		}
            	}
             }        
        }
        
        
        protected override void OnPositionClosed(Position pos)
         {
          a=0;
         }
         
          protected override void OnStop()
        {
         Print("Successful day!");
        }

    }
}